/*
  readevents.c

  This is an example file to accompany cosmo version 1.1.11.
  
  There are two simple output data formats supported by cosmo 1.1.11.
  These are "binary" and "paw24".  The "paw24" format will disappear in
  some future release.  It consists of the first 24 adc values for each
  event, space delimited with one line per pixel readout.

  The other format is "binary".  This program is an example of how you
  might read events from such a binary file.  
  The format for each event is a series of 16bit integers.  The first
  integer is the count.  This is followed by "count" additional integers
  which is the event.  cosmo 1.1.11 outputs 256 16bit samples per event
  so you should find a "256" followed by 256 16bit integers.

  The example below prompts you for the filename, then after you press
  ENTER, will call the getevent() subroutine and print out the first
  10 samples from each readout.

  On linux, you could compile this program with the following:

         gcc -o readevents readevents.c -lm -lc



  Mar 13, 2003 -JD
*/

#include <stdio.h>
#include <errno.h>
#include <string.h>

unsigned char evbuffer[32768]; 

FILE *infile;
char tempstr[256];


/*******************************************************************/


int openevfile(char *fname)
{
  
  infile = fopen(fname, "r"); 
  printf("Opening: %s\n", fname);
  if (infile == NULL) {
    return(2);
  }
  return(0);
}


int getevent(short int *ricount, char *evbuffer)
{
  
  short int icount;
  int itemp;
  /* read status */
  itemp = fread(&icount, 2, 1, infile);
  if (itemp < 1) {
    return(2);
  }
  
  *ricount=icount;
  itemp = fread(evbuffer, 2, icount, infile);
  if (itemp < 1) {
    return(2);
  }
  
  return(0);
}


main()
{
  int ireturn;
  int i;
  short int eventdata[16384];
  short int icount; 
  char c; 
  printf("Please enter data filename * ");
  (void) fgets(tempstr, sizeof(tempstr)-1, stdin);
  tempstr[strlen(tempstr)-1] = '\0'; /* cut off EOLN */
  if (strlen(tempstr) >= 1) {
    printf("Please press <CR> to begin reading from %s. * ",
	   tempstr);
    c = getc(stdin);
  }
  
  ireturn = openevfile(tempstr);
  if (ireturn != 0) {
    printf("ERROR: openevfile returned: %d\n", ireturn);
    exit(1);
  }
  
  /* print out upto 10000 events from the run data file */
  for (i = 0; i < 10000; i++) {
    ireturn = getevent(&icount, (char *) eventdata);
    
    printf("return:%d   count:%d   DATA: %d %d %d %d %d %d %d %d %d %d\n",
	   ireturn, icount, eventdata[0], eventdata[1],
	   eventdata[2], eventdata[3],
	   eventdata[4], eventdata[5],
	   eventdata[6], eventdata[7],
	   eventdata[8], eventdata[9]);
    
    
    if (ireturn != 0) exit(1);
  }
  
  
  exit(0);
}

